import fs from "fs";
import { fileURLToPath } from "url";
import { notFoundTemplate, subpathNotUsedTemplate } from "../../template/4xx.js";
import { stripBase } from "./util.js";
const HAS_FILE_EXTENSION_REGEXP = /^.*\.[^\\]+$/;
function vitePluginAstroPreview(settings) {
  const { base, outDir, trailingSlash } = settings.config;
  return {
    name: "astro:preview",
    apply: "serve",
    configurePreviewServer(server) {
      server.middlewares.use((req, res, next) => {
        if (!req.url.startsWith(base)) {
          res.statusCode = 404;
          res.end(subpathNotUsedTemplate(base, req.url));
          return;
        }
        const pathname = stripBase(req.url, base);
        const isRoot = pathname === "/";
        if (!isRoot) {
          const hasTrailingSlash = pathname.endsWith("/");
          if (hasTrailingSlash && trailingSlash == "never") {
            res.statusCode = 404;
            res.end(notFoundTemplate(pathname, 'Not Found (trailingSlash is set to "never")'));
            return;
          }
          if (!hasTrailingSlash && trailingSlash == "always" && !HAS_FILE_EXTENSION_REGEXP.test(pathname)) {
            res.statusCode = 404;
            res.end(notFoundTemplate(pathname, 'Not Found (trailingSlash is set to "always")'));
            return;
          }
        }
        next();
      });
      return () => {
        server.middlewares.use((req, res) => {
          const errorPagePath = fileURLToPath(outDir + "/404.html");
          if (fs.existsSync(errorPagePath)) {
            res.statusCode = 404;
            res.setHeader("Content-Type", "text/html;charset=utf-8");
            res.end(fs.readFileSync(errorPagePath));
          } else {
            const pathname = stripBase(req.url, base);
            res.statusCode = 404;
            res.end(notFoundTemplate(pathname, "Not Found"));
          }
        });
      };
    }
  };
}
export {
  vitePluginAstroPreview
};
