import { HTMLParts } from "../common.js";
import { createScopedResult, ScopeFlags } from "../scope.js";
import { isHeadAndContent } from "./head-and-content.js";
import { renderAstroTemplateResult } from "./render-template.js";
function isAstroComponentFactory(obj) {
  return obj == null ? false : obj.isAstroComponentFactory === true;
}
async function renderToString(result, componentFactory, props, children) {
  const scoped = createScopedResult(result, ScopeFlags.Astro);
  const factoryResult = await componentFactory(scoped, props, children);
  if (factoryResult instanceof Response) {
    const response = factoryResult;
    throw response;
  }
  let parts = new HTMLParts();
  const templateResult = isHeadAndContent(factoryResult) ? factoryResult.content : factoryResult;
  for await (const chunk of renderAstroTemplateResult(templateResult)) {
    parts.append(chunk, result);
  }
  return parts.toString();
}
function isAPropagatingComponent(result, factory) {
  let hint = factory.propagation || "none";
  if (factory.moduleId && result.propagation.has(factory.moduleId) && hint === "none") {
    hint = result.propagation.get(factory.moduleId);
  }
  return hint === "in-tree" || hint === "self";
}
export {
  isAPropagatingComponent,
  isAstroComponentFactory,
  renderToString
};
